#!/usr/bin/env python
'''
This package installs a prebuilt version of PyQt5 for Mac OS. It does not
compile anything because uses an already precompiled one.

The main tools used to build PyQt5 depend on the package version:

    - 5.4.2.x: installs PyQt 5.4.2 built with SIP 4.16.8 and Python 3.4.3

Remember that Qt5 has to be installed already in your system in order to be
able to use PyQt5. On MAC OS, you can install Qt5 using brew:

    brew install qt5

WINDOWS and LINUX are NOT SUPPORTED by this script yet, sorry.

Usage:
    pyqt5_macos_built.py [-h]

Options:
    -h --help           Shows this screen

'''
import os
import site
from docopt import docopt
from collections import namedtuple

if __name__ == '__main__':
    arguments = docopt(__doc__)

    links = []
    Link = namedtuple('Link', 'src dest')

    # Executable files
    bin_path = os.environ.get('VIRTUAL_ENV', '/usr/local')
    site_path = site.getsitepackages()[0]

    bin_files = os.listdir(site.getsitepackages()[0] + '/PyQt5/bin/')
    for bin_file in bin_files:
        src = site_path + '/PyQt5/bin/' + bin_file
        dest = bin_path + '/bin/' + bin_file
        links.append(Link(src=src, dest=dest))

    # Libraries
    src = site_path + '/PyQt5/lib/sip.so'
    dest = site_path
    links.append(Link(src=src, dest=dest))

    for link in links: print(link)
